@@ -12,8 +12,13 @@
 test <- function(pkg = ".", filter = NULL, fresh = FALSE) {
   pkg <- as.package(pkg)
 
-  path_test <- file.path(pkg$path, "inst", "tests")
-  if (!file.exists(path_test)) return()
+  test_path <- find_test_dir(pkg$path)
+  test_files <- dir(test_path, "^test.*\\.[rR]$")
+  if (length(test_files) == 0) {
+    message("No tests found: no files matching pattern '^test.*\\.[rR]$'",
+      "found in inst/tests")
+    return(invisible())
+  }
 
   message("Testing ", pkg$package)
   if (fresh) {
@@ -22,7 +27,7 @@ test <- function(pkg = ".", filter = NULL, fresh = FALSE) {
       require("testthat", quiet = TRUE)
 
       load_all(.(pkg$path), quiet = TRUE)
-      test_dir(.(path_test), filter = .(filter))
+      test_dir(.(test_path), filter = .(filter))
     })
     eval_clean(to_run)
   } else {
@@ -30,10 +35,20 @@ test <- function(pkg = ".", filter = NULL, fresh = FALSE) {
     # Run tests in a child of the namespace environment, like testthat::test_package
     load_all(pkg)
     env <- new.env(parent = ns_env(pkg))
-    with_envvar(r_env_vars(), test_dir(path_test, filter = filter, env = env))
+    with_envvar(r_env_vars(), test_dir(test_path, filter = filter, env = env))
   }
 }
 
+find_test_dir <- function(path) {
+  testthat <- file.path(path, "tests", "testthat")
+  if (file.exists(testthat)) return(testthat)
+
+  inst <- file.path(path, "inst", "tests")
+  if (file.exists(inst)) return(inst)
+
+  stop("No testthat directories found in ", path, call. = FALSE)
+}
+
 
 #' Return the path to one of the packages in the devtools test dir
 #'
@@ -41,17 +56,17 @@ test <- function(pkg = ".", filter = NULL, fresh = FALSE) {
 #' returns the path to them.
 #'
 #' @param package Name of the test package.
+#' @keywords internal
 #' @examples
 #' if (has_tests()) {
-#' devtest("collate-extra")
+#' devtest("testData")
 #' }
 #' @export
 devtest <- function(package) {
-  if (is.null(dev_meta("devtools"))) {
-    # devtools was loaded the normal way
-    system.file(package = "devtools", "tests", package)
-  } else {
-    # devtools was loaded with load_all
-    system.file(package = "devtools", "inst", "tests", package)
-  }
+  stopifnot(has_tests())
+
+  path <- system.file(package = "devtools", "tests", "testthat", package)
+  if (path == "") stop(package, " not found", call. = FALSE)
+
+  path
 }
